==> recime-bot-runtime-2017.10.21208.tgz: package/src/telegram.ts <==
import fs = require('fs');
import util = require('util');
import request = require('request');

import {Channel} from "./channel";
import {Logger} from "./logger";

export class Telegram extends Channel {
    private logger: any;
    
     constructor(params: any){
         super({
             homedir : params.homedir,
             uid : params.uid,
             platform : 'telegram'
         });
     }

     execute(body, parameters, handler){
         const uid = this.params.uid;

         return new Promise((resolve, reject)=>{
             Logger.init(this.params).then((logger)=>{
                    logger.incoming(body);

                    handler(uid, body, this.params.platform, (result)=>{
                        // force to array. 
                        result = Array.isArray(result) ? result : [result];
                        
                        this.sendMessage(0, result, body, logger).then(()=>{
                            resolve();
                        });
                  }, (err)=> resolve(err));
            });
        });
     }

     sendMessage(index, messages, body, logger){
        return new Promise((resolve, reject)=>{ 
            const supportedMethods = [
                "message",
                "photo",
                "audio",
                "document",
                "location",
                "venue",
                "contact"
            ];
            const message = messages[index];
            let method = "sendMessage";
            
            if (message.type && supportedMethods.indexOf(message.type.toLowerCase()) >= 0){
                method = message.type.toLowerCase();
                method = `send${method.substr(0, 1).toUpperCase()}${method.substr(1, method.length - 1)}`;
            }
            const uri = `https://api.telegram.org/bot${process.env.TELEGRAM_ACCESS_TOKEN || process.env.RECIME_TELEGRAM_ACCESS_TOKEN}/${method}`;

            let options:any = {
                uri : uri,
                method : "POST",
                json : message.payload || message
            };

            options.json.chat_id = body.message.chat.id;

            request(options, (err, response, result)=>{
                logger.outgoing(options, result);

                if (!err && response.statusCode === 200){
                    if (index + 1 < messages.length){
                        this.sendMessage(++index, messages, body, logger).then(resolve);
                    } else {
                        return resolve();
                    }  
                } else {
                    resolve({
                        message : {
                            text: JSON.stringify(result.error || response.body),
                            chat_id : options.json.chat_id
                        }
                    });
                }
            });
        });
     }
}

==> recime-bot-runtime-2017.10.30938.tgz: package/src/telegram.ts <==
import fs = require('fs');
import util = require('util');
import request = require('request');

import {Channel} from "./channel";
import {Logger} from "./logger";

export class Telegram extends Channel {
    private logger: any;
    
     constructor(params: any){
         super({
             homedir : params.homedir,
             uid : params.uid,
             platform : 'telegram'
         });
     }

     execute(body, parameters, handler){
         const uid = this.params.uid;

         return new Promise((resolve, reject)=>{
             Logger.init(this.params).then((logger)=>{
                    logger.incoming(body);

                    handler(uid, body, this.params.platform, (result)=>{
                        // force to array. 
                        result = result.length ? result : [result];
                        
                        this.sendMessage(0, result, body, logger).then(()=>{
                            resolve();
                        });
                  }, (err)=> resolve(err));
            });
        });
     }

     sendMessage(index, messages, body, logger){
        return new Promise((resolve, reject)=>{ 
            const supportedMethods = [
                "message",
                "photo",
                "audio",
                "document",
                "location",
                "venue",
                "contact"
            ];
            const message = messages[index];
            let method = "sendMessage";
            
            if (message.type && supportedMethods.indexOf(message.type.toLowerCase()) >= 0){
                method = message.type.toLowerCase();
                method = `send${method.substr(0, 1).toUpperCase()}${method.substr(1, method.length - 1)}`;
            }
            const uri = `https://api.telegram.org/bot${process.env.TELEGRAM_ACCESS_TOKEN || process.env.RECIME_TELEGRAM_ACCESS_TOKEN}/${method}`;

            let options:any = {
                uri : uri,
                method : "POST",
                json : message.payload || message
            };

            options.json.chat_id = body.message.chat.id;

            request(options, (err, response, result)=>{
                logger.outgoing(options, result);

                if (!err && response.statusCode === 200){
                    if (index + 1 < messages.length){
                        this.sendMessage(++index, messages, body, logger).then(resolve);
                    } else {
                        return resolve();
                    }  
                } else {
                    resolve({
                        message : {
                            text: JSON.stringify(result.error || response.body),
                            chat_id : options.json.chat_id
                        }
                    });
                }
            });
        });
     }
}
